==> aroundme_0_5_1.zip: aroundme_0_5_1/aroundme/template/barnraiser_01/search.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>

<form action="search.php" method="post">

<table width="100%" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="560" valign="top">
			<div class="box_top">
				<?php echo $lang['section_search'];?><br />
			</div>

			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="2" cellspacing="2" border="0">
				<tr>
					<td>
						<?php echo $lang['txt_search_basic_intro'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<div class="box_edit">
						<table cellpadding="2" cellspacing="0" border="0" width="100%">
							<tr>
								<td>
									<table cellpadding="4" cellspacing="0" border="0">
										<tr>
											<td>
												<input type="text" name="search_text" size="20" value="<?php if (isset($search_text)) { echo $search_text;};?>" /><br />
											</td>
											<td>
												<input type="image" src="<?php echo $templatePath;?>img/search.png" value="search" class="checkbox" /><br />
											</td>
										</tr>
									</table>
								</td>
							</tr>
						</table>
						</div>
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<?php
			if (isset($search_text)) {
			?>
			<table width="100%" cellpadding="0" cellspacing="4" border="0">
				<tr>
					<td>
						<?php echo $lang['txt_search_results'];?><br />
					</td>
				</tr>
			</table>
			<?php }?>



			<?php
			if (isset($blogs)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_blogs'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($blogs as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['blog_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>


			<?php
			if (isset($subjects)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_subjects'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($subjects as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0" class="table_nested">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['subject_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>


			<?php
			if (isset($groups)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_groups'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($groups as $key => $i):
				?>
				<tr>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a><br />
									<span class="txt_footer">
									<?php echo $i['group_synopsis'];?><br />
									</span>
								</td>
								<td nowrap="nowrap" align="right">
									<?php echo $lang['txt_recommended_age'];?>:
									<?
									if ($i['group_from_age'] && $i['group_to_age']) {
									    echo $i['group_from_age'] . "/" . $i['group_to_age'];
									}
									else if ($i['group_from_age'] && !$i['group_to_age']) {
										echo $lang['txt_age_from'] . " " . $i['group_from_age'];
									}
									else if (!$i['group_from_age'] && $i['group_to_age']) {
										echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
									}
									else {
										echo $lang['txt_age_all'];
									}
									?><br />
									<?php echo $lang['txt_genre'];?>: <?php if (isset($i['genre_id'])) { echo $lang['arr_genre'][$i['genre_id']];}?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>


			<?php
			if (isset($polls)) {
 			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_polls'];?><br />
			</span>
			<table border="0" cellspacing="4" cellpadding="0" width="100%">
 				<?php
 				foreach($polls as $key => $i):
 				?>
 				<tr>
 					<td valign="top">
 						<?php
						$poll = $i;
						$poll_url = "mag_item.php?poll_id=" . $i['poll_id'];
 						include $templatePath . "poll.inc.tpl.php";
 						?>
 					</td>
 			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
 				<?php
 				endforeach;
 				?>
 			</table>
			<?php }?>


			<?php
			if (isset($library_items)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_library_items'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($library_items as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0" class="table_nested">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?library_id=<?php echo $i['library_id'];?>"><?php echo $i['library_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['library_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>


			<?php
			if (isset($tasks)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_tasks'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($tasks as $key => $i):
				?>
			     <tr>
					<td width="3" valign="top">
						<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
					</td>
					<td valign="top">
						<a href="sch_item.php?schedule_id=<?php echo $i['schedule_id'];?>"><?php echo $i['schedule_title'];?></a><br />
						<?php echo $i['schedule_synopsis'];?><br />
					</td>
					<td align="right" valign="top" nowrap="nowrap">
						<?php echo $i['display_schedule_start_datetime'];?><br />
						<?php echo $i['schedule_allocation'];?><br />
					</td>
			    </tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>



			<?php
			if (isset($activities)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_activities'];?><br />
			</span>
			<table width="100%" cellpadding="2" cellspacing="2" border="0">
				<?php
				foreach($activities as $key => $i):
				?>
			     <tr>
					<td width="3" valign="top">
						<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
					</td>
					<td>
						<a href="sch_item.php?schedule_id=<?php echo $i['schedule_id'];?>"><?php echo $i['schedule_title'];?></a><br />
						<?php echo $i['schedule_synopsis'];?><br />
					</td>
					<td align="right" valign="top">
						<?php echo $i['display_schedule_start_datetime'];?><br />
					</td>
			    </tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>

			<table width="100%" cellpadding="2" cellspacing="2" border="0">
				<tr>
					<td>
						<div class="box_edit">
							<?php
							if (isset($users)) {
							?>
							<table border="0" width="100%" cellspacing="0" cellpadding="4">
								<tr>
									<td valign="top">
										<?php
											foreach ($users as $key => $i) :
										?>
												<a href="msg_compose.php?to_user_id=<?php echo $i['user_id']?>"><?php echo $i['profile_nic']?></a><br />
										<?php
											endforeach;
										?>
									</td>
								</tr>
							</table>
							<?php }?>
							</div>
					</td>
				</tr>
			</table>

			</div>

			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>
</form>

==> aroundme_0_5_3.zip: aroundme_0_5_3/aroundme/template/barnraiser_01/search.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>

<form action="search.php" method="post">

<table width="100%" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<?php
		if (isset($group)) {
		?>
		<td width="180" valign="top">
			<?php
			include $templatePath . "g_menu.inc.tpl.php";
			?>
		</td>
		
		<td width="20">
			<img src="<?php echo $templatePath;?>img/pixel.png" width="20" height="1" alt="" /><br />
		</td>
		
		<td width="560" valign="top">
		<?php } else {?>
		<td width="760" valign="top">
		<?php }?>
			
			<div class="box_top">
				<?php echo $lang['section_search'];?><br />
			</div>

			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="2" cellspacing="2" border="0">
				<tr>
					<td>
						<?php 
						if (isset($group)) {
							echo $lang['txt_search_basic_intro_group'];
						}
						else {
							echo $lang['txt_search_basic_intro'];
						}
						?><br />
					</td>
				</tr>
				<tr>
					<td>
						<div class="box_edit">
						<table cellpadding="2" cellspacing="0" border="0" width="100%">
							<tr>
								<td width="70%">
									<?php
									$tags = "";
									
									if (isset($group)) {
										echo "<b>" . $lang['txt_tag_group'] . "</b><br />";
										if (isset($group_tags)) {
											foreach ($group_tags as $key => $i):
												$tags .= "<a href='search.php?group_id=" . $group['group_id']. "&amp;tag=" . $i['tag_body']. "'>" . $i['tag_body'] . "</a>";
												
												if ($i['user_id'] == $me['user_id']) {
													$tags .= "*";
												}
												
												if (count($group_tags) > $key+1) {
													$tags .= ", ";
												}
											endforeach;
										}
									}
									else {
										if (isset($network_tags)) {
											echo "<b>" . $lang['txt_tag_network'] . "</b><br />";
											foreach ($network_tags as $key => $i):
												$tags .= "<a href='search.php?tag=" . $i['tag_body']. "'>" . $i['tag_body'] . "</a>";
												
												if ($i['user_id'] == $me['user_id']) {
													$tags .= "*";
												}
												
												if (count($network_tags) > $key+1) {
													$tags .= ", ";
												}
											endforeach;
										}
										
									}
									
									echo $tags;
									?>
								</td>
								<?php 
								if (!isset($group)) {
								?>
								<td width="30%">
									<b><?php echo $lang['txt_search'];?></b><br />
									<table cellpadding="0" cellspacing="0" border="0">
										<tr>
											<td>
												<input type="text" name="search_text" size="20" value="<?php if (isset($search_text)) { echo $search_text;};?>" /><br />
											</td>
											<td>
												<input type="image" src="<?php echo $templatePath;?>img/search.png" value="search" class="checkbox" /><br />
											</td>
										</tr>
									</table>
								</td>
								<?php }?>
							</tr>
						</table>
						</div>
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<?php
			if (isset($search_text)) {
			?>
			<table width="100%" cellpadding="0" cellspacing="4" border="0">
				<tr>
					<td>
						<?php echo $lang['txt_search_results'];?><br />
					</td>
				</tr>
			</table>
			<?php }?>



			<?php
			if (isset($blogs)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_blogs'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($blogs as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<?php
									if (isset($group)) {
										$url = "blg_item.php?group_id=" . $group['group_id'] . "&amp;blog_id=" . $i['blog_id'];
									}
									else {
										$url = "mag_item.php?blog_id=" . $i['blog_id'];
									}
									?>
									<a href="<?php echo $url;?>"><?php echo $i['blog_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<b><?php echo $i['blog_title'];?></b><br />
									<?php echo dots(200, $i['blog_synopsis']);?><br />
								</td>
							</tr>
							<tr>
								<td>
									<br />
								</td>
								<td>
									<?php echo $lang['txt_tag'];?>: 
	
									<?php
									$tags = "";
									if (isset($i['tags'])) {
										foreach ($i['tags'] as $keyt => $t):
											$tags .= $t['tag_body'];
											
											if (count($i['tags']) > $keyt+1) {
												$tags .= ", ";
											}
										endforeach;
										$tags = searchTextFormat($tag, $tags);
										echo $tags;
									}
									?>
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>


			<?php
			if (isset($subjects)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_subjects'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($subjects as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0" class="table_nested">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<?php
									if (isset($group)) {
										$url = "frm_item.php?group_id=" . $group['group_id'] . "&amp;subject_id=" . $i['subject_id'];
									}
									else {
										$url = "mag_item.php?subject_id=" . $i['subject_id'];
									}
									?>
									<a href="<?php echo $url;?>"><?php echo $i['subject_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['subject_title'];?><br />
									<?php echo dots(200, $i['subject_body']);?><br />
								</td>
							</tr>
							<tr>
								<td>
									<br />
								</td>
								<td>
									<?php echo $lang['txt_tag'];?>: 
									
									<?php
									$tags = "";
									if (isset($i['tags'])) {
										foreach ($i['tags'] as $keyt => $t):
											$tags .= $t['tag_body'];
											
											if (count($i['tags']) > $keyt+1) {
												$tags .= ", ";
											}
										endforeach;
										$tags = searchTextFormat($tag, $tags);
										echo $tags;
									}
									?>
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>


			<?php
			if (isset($groups)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_groups'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($groups as $key => $i):
				?>
				<tr>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a><br />
									<span class="txt_footer">
									<?php echo $i['group_synopsis'];?><br />
									</span>
								</td>
								<td nowrap="nowrap" align="right">
									<?php echo $lang['txt_recommended_age'];?>:
									<?
									if ($i['group_from_age'] && $i['group_to_age']) {
									    echo $i['group_from_age'] . "/" . $i['group_to_age'];
									}
									else if ($i['group_from_age'] && !$i['group_to_age']) {
										echo $lang['txt_age_from'] . " " . $i['group_from_age'];
									}
									else if (!$i['group_from_age'] && $i['group_to_age']) {
										echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
									}
									else {
										echo $lang['txt_age_all'];
									}
									?><br />
									<?php echo $lang['txt_genre'];?>: <?php if (isset($i['genre_id'])) { echo $lang['arr_genre'][$i['genre_id']];}?><br />
								</td>
							</tr>
							<tr>
								<td>
									<br />
								</td>
								<td>
									<?php echo $lang['txt_tag'];?>: 
	
									<?php
									$tags = "";
									if (isset($i['tags'])) {
										foreach ($i['tags'] as $keyt => $t):
											$tags .= $t['tag_body'];
											
											if (count($i['tags']) > $keyt+1) {
												$tags .= ", ";
											}
										endforeach;
										$tags = searchTextFormat($tag, $tags);
										echo $tags;
									}
									?>
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>


			<?php
			if (isset($polls)) {
 			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_polls'];?><br />
			</span>
			<table border="0" cellspacing="4" cellpadding="0" width="100%">
 				<?php
 				foreach($polls as $key => $i):
 				?>
 				<tr>
 					<td valign="top">
 						<?php
						if (isset($group)) {
							$poll_url = "pol_item.php?group_id=" . $group['group_id'] . "&amp;poll_id=" . $i['poll_id'];
						}
						else {
							$poll_url = "mag_item.php?poll_id=" . $i['poll_id'];
						}
						
						$poll = $i;
 						include $templatePath . "poll.inc.tpl.php";
 						?>
 					</td>
 			    </tr>
				<tr>
					<td>
						<?php echo $lang['txt_tag'];?>: 

						<?php
						$tags = "";
						if (isset($i['tags'])) {
							foreach ($i['tags'] as $keyt => $t):
								$tags .= $t['tag_body'];
								
								if (count($i['tags']) > $keyt+1) {
									$tags .= ", ";
								}
							endforeach;
							$tags = searchTextFormat($tag, $tags);
							echo $tags;
						}
						?>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
 				<?php
 				endforeach;
 				?>
 			</table>
			<?php }?>


			<?php
			if (isset($library_items)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_library_items'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($library_items as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0" class="table_nested">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<?php
									if (isset($group)) {
										$url = "lib_item.php?group_id=" . $group['group_id'] . "&amp;library_id=" . $i['library_id'];
									}
									else {
										$url = "mag_item.php?library_id=" . $i['library_id'];
									}
									?>
									<a href="<?php echo $url;?>"><?php echo $i['library_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<b><?php echo $i['library_title'];?></b><br />
									<?php echo $i['library_synopsis'];?><br />
								</td>
							</tr>
							<tr>
								<td>
									<br />
								</td>
								<td>
									<?php echo $lang['txt_tag'];?>: 
	
									<?php
									$tags = "";
									if (isset($i['tags'])) {
										foreach ($i['tags'] as $keyt => $t):
											$tags .= $t['tag_body'];
											
											if (count($i['tags']) > $keyt+1) {
												$tags .= ", ";
											}
										endforeach;
										$tags = searchTextFormat($tag, $tags);
										echo $tags;
									}
									?>
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>


			<?php
			if (isset($tasks)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_tasks'];?><br />
			</span>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($tasks as $key => $i):
				?>
			     <tr>
					<td width="3" valign="top">
						<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
					</td>
					<td valign="top">
						<?php
						if (isset($group)) {
							$url = "sch_item.php?group_id=" . $group['group_id'] . "&amp;schedule_id=" . $i['schedule_id'];
						}
						else {
							$url = "sch_item.php?schedule_id=" . $i['schedule_id'];
						}
						?>			
						<a href="<?php echo $url;?>"><?php echo $i['schedule_title'];?></a><br />
						<?php echo $i['schedule_synopsis'];?><br />
					</td>
					<td align="right" valign="top" nowrap="nowrap">
						<?php echo $i['display_schedule_start_datetime'];?><br />
						<?php echo $i['schedule_allocation'];?><br />
					</td>
			    </tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>



			<?php
			if (isset($activities)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<span class="txt_item_title">
				<?php echo $lang['hdr_activities'];?><br />
			</span>
			<table width="100%" cellpadding="2" cellspacing="2" border="0">
				<?php
				foreach($activities as $key => $i):
				?>
			     <tr>
					<td width="3" valign="top">
						<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
					</td>
					<td>
						<?php
						if (isset($group)) {
							$url = "sch_item.php?group_id=" . $group['group_id'] . "&amp;schedule_id=" . $i['schedule_id'];
						}
						else {
							$url = "sch_item.php?schedule_id=" . $i['schedule_id'];
						}
						?>	
						<a href="<?php echo $url;?>"><?php echo $i['schedule_title'];?></a><br />
						<?php echo $i['schedule_synopsis'];?><br />
					</td>
					<td align="right" valign="top">
						<?php echo $i['display_schedule_start_datetime'];?><br />
					</td>
			    </tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>

			<table width="100%" cellpadding="2" cellspacing="2" border="0">
				<tr>
					<td>
						<div class="box_edit">
							<?php
							if (isset($users)) {
							?>
							<table border="0" width="100%" cellspacing="0" cellpadding="4">
								<tr>
									<td valign="top">
										<?php
											foreach ($users as $key => $i) :
										?>
												<a href="msg_compose.php?to_user_id=<?php echo $i['user_id']?>"><?php echo $i['profile_nic']?></a><br />
										<?php
											endforeach;
										?>
									</td>
								</tr>
							</table>
							<?php }?>
							</div>
					</td>
				</tr>
			</table>

			</div>

			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>
</form>
